@@ -236,6 +236,7 @@ t_testbed_add_device(UMockdevTestbedFixture * fixture, UNUSED_DATA)
             /* attributes */
             "idVendor", "0815", "idProduct", "AFFE", NULL,
             /* properties */
+            "DEVTYPE", "usb_device", "DEVNAME", "/dev/mydev",
             "ID_INPUT", "1", "ID_INPUT_KEYBOARD", "1", NULL);
     g_assert(syspath);
     g_assert(g_str_has_suffix(syspath, "/sys/devices/extkeyboard1"));
@@ -246,6 +247,8 @@ t_testbed_add_device(UMockdevTestbedFixture * fixture, UNUSED_DATA)
     g_assert(device != NULL);
     g_assert_cmpstr(udev_device_get_syspath(device), ==, syspath);
     g_assert_cmpstr(udev_device_get_action(device), ==, "add");
+    g_assert_cmpstr(udev_device_get_devnode(device), ==, "/dev/mydev");
+    g_assert_cmpstr(udev_device_get_devtype(device), ==, "usb_device");
     udev_device_unref(device);
     udev_monitor_unref(udev_mon);
     udev_unref(udev);
@@ -614,6 +617,7 @@ t_testbed_uevent_libudev(UMockdevTestbedFixture * fixture, UNUSED_DATA)
     g_assert(device != NULL);
     g_assert_cmpstr(udev_device_get_syspath(device), ==, syspath);
     g_assert_cmpstr(udev_device_get_action(device), ==, "add");
+    g_assert_cmpstr(udev_device_get_subsystem(device), ==, "pci");
     g_assert_cmpstr(udev_device_get_sysattr_value(device, "idVendor"), ==, "0815");
     g_assert_cmpstr(udev_device_get_property_value(device, "ID_INPUT"), ==, "1");
     udev_device_unref(device);
@@ -622,6 +626,7 @@ t_testbed_uevent_libudev(UMockdevTestbedFixture * fixture, UNUSED_DATA)
     g_assert(device != NULL);
     g_assert_cmpstr(udev_device_get_syspath(device), ==, syspath);
     g_assert_cmpstr(udev_device_get_action(device), ==, "add");
+    g_assert_cmpstr(udev_device_get_subsystem(device), ==, "pci");
     g_assert_cmpstr(udev_device_get_sysattr_value(device, "idVendor"), ==, "0815");
     g_assert_cmpstr(udev_device_get_property_value(device, "ID_INPUT"), ==, "1");
     udev_device_unref(device);
@@ -841,7 +846,7 @@ t_testbed_uevent_action_overflow(UMockdevTestbedFixture * fixture, UNUSED_DATA)
 
     /* overly long action */
     if (g_test_subprocess()) {
-        char long_action[4096];
+        char long_action[16384];
         memset(long_action, 'a', sizeof(long_action));
         long_action[sizeof(long_action)-1] = '\0';
         umockdev_testbed_uevent(fixture->testbed, syspath, long_action);
@@ -851,6 +856,25 @@ t_testbed_uevent_action_overflow(UMockdevTestbedFixture * fixture, UNUSED_DATA)
     g_test_trap_assert_stderr ("*uevent_sender_send*Property buffer overflow*");
 }
 
+static void
+t_testbed_uevent_property_overflow(UMockdevTestbedFixture * fixture, UNUSED_DATA)
+{
+    /* overly long property */
+    if (g_test_subprocess()) {
+        char long_name[10000];
+        memset(long_name, 'a', sizeof long_name);
+        long_name[sizeof long_name - 1] = '\0';
+
+        /* this sends an "add" uevent */
+        umockdev_testbed_add_device(fixture->testbed, "pci", "mydev", NULL,
+                                    NULL, /* attributes */
+                                    long_name, long_name, NULL);
+    }
+    g_test_trap_subprocess(NULL, 0, 0);
+    g_test_trap_assert_failed();
+    g_test_trap_assert_stderr ("*uevent_sender_send*Property buffer overflow*");
+}
+
 static void
 t_testbed_add_from_string(UMockdevTestbedFixture * fixture, UNUSED_DATA)
 {
@@ -2300,6 +2324,8 @@ main(int argc, char **argv)
 	       t_testbed_uevent_null_action, t_testbed_fixture_teardown);
     g_test_add("/umockdev-testbed/uevent/action_overflow", UMockdevTestbedFixture, NULL, t_testbed_fixture_setup,
 	       t_testbed_uevent_action_overflow, t_testbed_fixture_teardown);
+    g_test_add("/umockdev-testbed/uevent/property_overflow", UMockdevTestbedFixture, NULL, t_testbed_fixture_setup,
+	       t_testbed_uevent_property_overflow, t_testbed_fixture_teardown);
 
     /* tests for mocking USB devices */
     g_test_add("/umockdev-testbed-usb/lsusb", UMockdevTestbedFixture, NULL, t_testbed_fixture_setup,
